@@ -1,90 +1,118 @@
-( cd opt/kde/lib ; rm -rf libkaudiodevicelist.so )
-( cd opt/kde/lib ; ln -sf libkaudiodevicelist.so.4 libkaudiodevicelist.so )
-( cd opt/kde/lib ; rm -rf libkaudiodevicelist.so.4 )
-( cd opt/kde/lib ; ln -sf libkaudiodevicelist.so.4.1.0 libkaudiodevicelist.so.4 )
-( cd opt/kde/share/icons ; rm -rf default.kde4 )
-( cd opt/kde/share/icons ; ln -sf oxygen default.kde4 )
-( cd opt/kde/share/doc/HTML/en/knetattach ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/knetattach ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/khelpcenter/visualdict ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/khelpcenter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libkwalletbackend.so )
+( cd opt/kde/lib ; ln -sf libkwalletbackend.so.4 libkwalletbackend.so )
+( cd opt/kde/lib ; rm -rf libkwalletbackend.so.4 )
+( cd opt/kde/lib ; ln -sf libkwalletbackend.so.4.2.0 libkwalletbackend.so.4 )
+( cd opt/kde/share/doc/HTML/en/kdesu ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kdesu ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/khelpcenter/faq ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/khelpcenter/quickstart ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/khelpcenter/glossary ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/khelpcenter/faq ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/khelpcenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/khelpcenter/userguide ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kioslave ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kioslave ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kdebugdialog ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kdesu ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kdesu ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/desktopbehavior ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/paths ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/paths ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/netpref ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/cookies ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/khelpcenter/visualdict ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/cgi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/cgi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/man ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/man ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/nfs ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/nfs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/smb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/smb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/tar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/tar ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/fish ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/fish ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/gzip ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/gzip ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/info ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/info ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/sftp ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/sftp ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/bzip2 ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/bzip2 ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/finger ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/finger ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/floppy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/floppy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/bookmarks ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/bookmarks ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/thumbnail ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/thumbnail ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/knetattach ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/knetattach ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/icons ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/passwords ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/performance ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/performance ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/emoticons ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/emoticons ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmlaunch ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmtaskbar ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/cache ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/helpindex ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/panel ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/panelappearance ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/smb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/spellchecking ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmkonsole ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/desktop ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/crypto ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/useragent ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/language ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/cookies ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/filetypes ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/proxy ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/background ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmnotify ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/desktop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/cache ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/email ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmcss ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/ebrowsing ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/icons ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/khtml ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/filemanager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/smb ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/panel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/paths ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/paths ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/proxy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/desktopbehavior ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/passwords ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/panelappearance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/ebrowsing ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/background ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/crypto ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/emoticons ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/emoticons ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/netpref ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmlaunch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmcss ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmnotify ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmkonsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/language ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/bookmarks ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/bookmarks ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/useragent ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/helpindex ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmtaskbar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/performance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcontrol/performance ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kdebugdialog ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/icons ; rm -rf default.kde4 )
+( cd opt/kde/share/icons ; ln -sf oxygen default.kde4 )
